@@ -298,9 +298,21 @@ class APIVisitor(APIParserVisitor):
         self.errorMsg = errorMsg
 
     def visitSpool(self, ctx: APIParser.SpoolContext):
-        content = ctx.String().getText()
+        if ctx.SPOOL_EXPRESSION() is not None:
+            content = str(ctx.SPOOL_EXPRESSION().getText()).strip()
+            if content.startswith("'") and content.endswith("'"):
+                content = content[1:-1]
+            elif content.startswith('"') and content.endswith('"'):
+                content = content[1:-1]
+        else:
+            content = ""
 
-        parsedObject = {'name': 'SPOOL', 'file': content}
+        if ctx.SPOOL_OFF() is not None:
+            content = "OFF"
+        parsedObject = {
+            'name': 'SPOOL',
+            'file': content
+        }
 
         # 获取错误代码
         errorCode = 0
@@ -468,10 +480,19 @@ class APIVisitor(APIParserVisitor):
             parsedObject.update({"rule": "BREAK"})
         elif ctx.LOOP_CONTINUE():
             parsedObject.update({"rule": "CONTINUE"})
-        elif ctx.LOOP_BEGIN():
-            parsedObject.update({"rule": "BEGIN"})
-        else:
-            parsedObject.update({"rule": "UNTIL"})
+        elif ctx.LOOP_UNTIL():
+            if ctx.LOOP_BEGIN() is not None:
+                parsedObject.update({"rule": "BEGIN"})
+            else:
+                parsedObject.update({"rule": "UNTIL"})
+                # 如果有两个INT，则第一个是最大循环次数，第二个是循环间隔
+                # 如果只有一个INT，则第一个是循环间隔，没有最大循环次数
+                if len(list(ctx.LOOP_INT())) == 2:
+                    parsedObject.update({"interval": int(ctx.LOOP_INT()[1].getText())})
+                    parsedObject.update({"limit": int(ctx.LOOP_INT()[0].getText())})
+                else:
+                    parsedObject.update({"interval": int(ctx.LOOP_INT()[0].getText())})
+                    parsedObject.update({"limit": -1})
         if ctx.LOOP_EXPRESSION() is not None:
             expression = str(ctx.LOOP_EXPRESSION().getText())
             if expression.startswith("{%"):
@@ -479,7 +500,7 @@ class APIVisitor(APIParserVisitor):
             if expression.endswith("%}"):
                 expression = expression[:-2]
             expression = expression.strip()
-            parsedObject.update({"UNTIL": expression})
+            parsedObject.update({"until": expression})
 
         # 处理错误信息
         errorCode = 0
@@ -1449,4 +1470,3 @@ class APIVisitor(APIParserVisitor):
         self.parsedObject = parsedObject
         self.errorCode = errorCode
         self.errorMsg = errorMsg
-
