@@ -4,7 +4,10 @@ import json
 import os
 import re
 import traceback
-import glom
+try:
+    import glom
+except:
+    pass
 import ast
 from .sqlparse import SQLAnalyze
 from .apiparse import APIAnalyze
@@ -38,6 +41,7 @@ from .commands.apiSession import apiSessionManage
 from .commands.apiExecute import executeAPIStatement
 from .commands.apiExecute import executeAPISet
 from .commands.sqlExecute import executeSQLStatement
+from .common import rewriteStatement
 from .common import rewriteHintStatement
 from .common import rewriteSQLStatement
 from .common import rewriteAPIStatement
@@ -345,8 +349,8 @@ class CmdExecute(object):
 
             # 如果Hint中存在LogFilter，则结果集中过滤指定的输出信息
             if "LogFilter" in commandHints.keys():
-                for logfilter in commandHints["LogFilter"]:
-                    for item in rows[:]:
+                for logFilter in commandHints["LogFilter"]:
+                    for item in rows[::-1]:
                         # 将所有列用空格分隔来合并为一行
                         combinedRow = ""
                         for cell in item:
@@ -354,11 +358,16 @@ class CmdExecute(object):
                                 combinedRow = str(cell)
                             else:
                                 combinedRow = combinedRow + " " + str(cell)
-                        if "TESTCLI_DEBUG" in os.environ:
-                            print("[DEBUG] Will apply filter: [" + combinedRow + "] with " + logfilter)
-                        if re.match(pattern=logfilter, string=combinedRow, flags=re.IGNORECASE):
+                        if re.match(pattern=logFilter, string=combinedRow, flags=re.IGNORECASE):
+                            if "TESTCLI_DEBUG" in os.environ:
+                                print("[DEBUG] Will apply filter: [" + combinedRow +
+                                      "] with " + logFilter + ". Matched.")
                             rows.remove(item)
                             continue
+                        else:
+                            if "TESTCLI_DEBUG" in os.environ:
+                                print("[DEBUG] Will apply filter: [" + combinedRow +
+                                      "] with " + logFilter + ". Not matched.")
 
             # 如果Hint中存在LogMask,则掩码指定的输出信息
             if "LogMask" in commandHints.keys():
@@ -404,119 +413,6 @@ class CmdExecute(object):
                     if bDataChanged:
                         rows[i] = tuple(rowResult)
 
-        # 处理状态消息中的信息
-        status = None
-        if "status" in result.keys():
-            status = result["status"]
-        if status is not None:
-            statusLineList = status.splitlines(keepends=False)
-            # 如果Hint中存在LogFilter，则结果集中过滤指定的输出信息
-            if "LogFilter" in commandHints.keys():
-                for logFilter in commandHints["LogFilter"]:
-                    for line in statusLineList:
-                        if "TESTCLI_DEBUG" in os.environ:
-                            print("[DEBUG] Will apply filter: [" + line + "] with " + logFilter)
-                        if re.match(pattern=logFilter, string=line, flags=re.IGNORECASE):
-                            statusLineList.remove(line)
-                            continue
-                result["status"] = "\n".join(statusLineList)
-            # 如果Hint中存在LogMask,则掩码指定的输出信息
-            if "LogMask" in commandHints.keys():
-                for i in range(0, len(statusLineList)):
-                    line = statusLineList[i]
-                    for sqlMaskListString in commandHints["LogMask"]:
-                        sqlMaskList = sqlMaskListString.split("=>")
-                        if len(sqlMaskList) == 2:
-                            sqlMaskPattern = sqlMaskList[0]
-                            sqlMaskTarget = sqlMaskList[1]
-                            if "TESTCLI_DEBUG" in os.environ:
-                                print("[DEBUG] Will apply mask:" + line +
-                                      " with " + sqlMaskPattern + "=>" + sqlMaskTarget)
-                            try:
-                                beforeReplace = line
-                                nIterCount = 0
-                                bDataChanged = False
-                                while True:
-                                    # 循环多次替代，一直到没有可替代为止
-                                    afterReplace = re.sub(sqlMaskPattern, sqlMaskTarget,
-                                                          beforeReplace, re.IGNORECASE)
-                                    if afterReplace == beforeReplace or nIterCount > 99:
-                                        newLine = afterReplace
-                                        break
-                                    beforeReplace = afterReplace
-                                    nIterCount = nIterCount + 1
-                                if newLine != line:
-                                    bDataChanged = True
-                                    line = newLine
-                                if bDataChanged:
-                                    statusLineList[i] = newLine
-                            except re.error:
-                                if "TESTCLI_DEBUG" in os.environ:
-                                    print('[DEBUG] traceback.print_exc():\n%s'
-                                          % traceback.print_exc())
-                                    print('[DEBUG] traceback.format_exc():\n%s'
-                                          % traceback.format_exc())
-                        else:
-                            if "TESTCLI_DEBUG" in os.environ:
-                                print("[DEBUG] LogMask Hint Error: " + commandHints["LogMask"])
-                result["status"] = "\n".join(statusLineList)
-
-        message = None
-        if "message" in result.keys():
-            message = result["message"]
-        if message is not None:
-            messageLineList = message.splitlines(keepends=False)
-            # 如果Hint中存在LogFilter，则结果集中过滤指定的输出信息
-            if "LogFilter" in commandHints.keys():
-                for logFilter in commandHints["LogFilter"]:
-                    for line in messageLineList:
-                        if "TESTCLI_DEBUG" in os.environ:
-                            print("[DEBUG] Will apply filter: [" + line + "] with " + logFilter)
-                        if re.match(pattern=logFilter, string=line, flags=re.IGNORECASE):
-                            messageLineList.remove(line)
-                            continue
-                result["message"] = "\n".join(messageLineList)
-            # 如果Hint中存在LogMask,则掩码指定的输出信息
-            if "LogMask" in commandHints.keys():
-                for i in range(0, len(messageLineList)):
-                    line = messageLineList[i]
-                    for sqlMaskListString in commandHints["LogMask"]:
-                        sqlMaskList = sqlMaskListString.split("=>")
-                        if len(sqlMaskList) == 2:
-                            sqlMaskPattern = sqlMaskList[0]
-                            sqlMaskTarget = sqlMaskList[1]
-                            if "TESTCLI_DEBUG" in os.environ:
-                                print("[DEBUG] Will apply mask:" + line +
-                                      " with " + sqlMaskPattern + "=>" + sqlMaskTarget)
-                            try:
-                                beforeReplace = line
-                                nIterCount = 0
-                                bDataChanged = False
-                                while True:
-                                    # 循环多次替代，一直到没有可替代为止
-                                    afterReplace = re.sub(sqlMaskPattern, sqlMaskTarget,
-                                                          beforeReplace, re.IGNORECASE)
-                                    if afterReplace == beforeReplace or nIterCount > 99:
-                                        newLine = afterReplace
-                                        break
-                                    beforeReplace = afterReplace
-                                    nIterCount = nIterCount + 1
-                                if newLine != line:
-                                    bDataChanged = True
-                                    line = newLine
-                                if bDataChanged:
-                                    messageLineList[i] = newLine
-                            except re.error:
-                                if "TESTCLI_DEBUG" in os.environ:
-                                    print('[DEBUG] traceback.print_exc():\n%s'
-                                          % traceback.print_exc())
-                                    print('[DEBUG] traceback.format_exc():\n%s'
-                                          % traceback.format_exc())
-                        else:
-                            if "TESTCLI_DEBUG" in os.environ:
-                                print("[DEBUG] LogMask Hint Error: " + commandHints["LogMask"])
-                result["message"] = "\n".join(messageLineList)
-
     """
         根据提示信息改写返回结果中的状态信息
         传入参数：
@@ -540,12 +436,18 @@ class CmdExecute(object):
             # 如果Hint中存在LogFilter，则结果集中过滤指定的输出信息
             if "LogFilter" in commandHints.keys():
                 for logFilter in commandHints["LogFilter"]:
-                    for line in statusLineList:
-                        if "TESTCLI_DEBUG" in os.environ:
-                            print("[DEBUG] Will apply filter: [" + line + "] with " + logFilter)
+                    # 从后往前删除，以避免漏掉一些东西
+                    for line in statusLineList[::-1]:
                         if re.match(pattern=logFilter, string=line, flags=re.IGNORECASE):
+                            if "TESTCLI_DEBUG" in os.environ:
+                                print("[DEBUG] Will apply filter: [" + line +
+                                      "] with " + logFilter + ". Matched.")
                             statusLineList.remove(line)
                             continue
+                        else:
+                            if "TESTCLI_DEBUG" in os.environ:
+                                print("[DEBUG] Will apply filter: [" + line +
+                                      "] with " + logFilter + ". Not matched.")
                 result["status"] = "\n".join(statusLineList)
             # 如果Hint中存在LogMask,则掩码指定的输出信息
             if "LogMask" in commandHints.keys():
@@ -610,13 +512,14 @@ class CmdExecute(object):
             # 如果Hint中存在LogFilter，则结果集中过滤指定的输出信息
             if "LogFilter" in commandHints.keys():
                 for logFilter in commandHints["LogFilter"]:
-                    for line in messageLineList:
+                    for line in messageLineList[::-1]:
                         if "TESTCLI_DEBUG" in os.environ:
                             print("[DEBUG] Will apply filter: [" + line + "] with " + logFilter)
                         if re.match(pattern=logFilter, string=line, flags=re.IGNORECASE):
                             messageLineList.remove(line)
                             continue
                 result["message"] = "\n".join(messageLineList)
+
             # 如果Hint中存在LogMask,则掩码指定的输出信息
             if "LogMask" in commandHints.keys():
                 for i in range(0, len(messageLineList)):
@@ -946,23 +849,25 @@ class CmdExecute(object):
                     )
                     if len(rewrotedCommandHintValueList) != 0:
                         commandHintList[commandHintKey] = commandHintNewValue
-                        yield {
-                            "type": "parse",
-                            "rawCommand": None,
-                            "formattedCommand": None,
-                            "rewrotedCommand":
-                                ["REWROTED Hint> " + str(commandHintKey) + ":" + str(commandHintNewValue), ],
-                            "script": commandScriptFile
-                        }
-            if "ScenarioName" in commandHintList:
-                scenarioName = str(commandHintList["ScenarioName"])
+
+            # 处理ScenarioId和ScenarioName, 他们总是成对出现
+            if "ScenarioId" in commandHintList:
                 scenarioId = str(commandHintList["ScenarioId"])
+                scenarioName = str(commandHintList["ScenarioName"])
                 if scenarioName.strip().upper() == 'END':
                     self.scenarioName = ""
                     self.scenarioId = ""
                 else:
                     self.scenarioName = scenarioName
                     self.scenarioId = scenarioId
+                rewrotedHint = "REWROTED Hint> --[Scenario:" + scenarioId + ":" + scenarioName + "]"
+                yield {
+                    "type": "parse",
+                    "rawCommand": None,
+                    "formattedCommand": None,
+                    "rewrotedCommand": [rewrotedHint, ],
+                    "script": commandScriptFile
+                }
 
             # 处理各种命令
             if "TESTCLI_DEBUG" in os.environ:
@@ -1173,9 +1078,25 @@ class CmdExecute(object):
                             lastCommandResult["errorCode"] = 1
                         yield commandResult
                 elif parseObject["name"] in ["SPOOL"]:
+                    # 根据语句中的变量或者其他定义信息来重写当前语句
+                    spoolFile = rewriteStatement(
+                        cls=self.cliHandler,
+                        statement=parseObject["file"],
+                        commandScriptFile=commandScriptFile
+                    )
+                    if spoolFile != parseObject["file"]:
+                        # 如果命令被发生了改写，要打印改写记录
+                        rewrotedHint = "REWROTED CMD> _SPOOL " + str(spoolFile)
+                        yield {
+                            "type": "parse",
+                            "rawCommand": None,
+                            "formattedCommand": None,
+                            "rewrotedCommand": [rewrotedHint,],
+                            "script": commandScriptFile
+                        }
                     for commandResult in spool(
                             cls=self.cliHandler,
-                            fileName=parseObject["file"]
+                            fileName=spoolFile
                     ):
                         if commandResult["type"] == "result":
                             lastCommandResult.clear()
