@@ -3,7 +3,7 @@ import time
 import paramiko
 import io
 import copy
-from ..common import rewiteStatement
+from ..common import rewriteStatement
 
 sshSession = {}
 sshCurrentSessionName = "NONAME"
@@ -73,22 +73,22 @@ def rewriteSshRequest(cls, requestObject, commandScriptFile: str):
 
     if "host" in requestObject:
         statement = requestObject["host"]
-        newStatement = rewiteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
+        newStatement = rewriteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
         if statement != newStatement:
             requestObject.update({"host": newStatement})
     if "user" in requestObject:
         statement = requestObject["user"]
-        newStatement = rewiteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
+        newStatement = rewriteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
         if statement != newStatement:
             requestObject.update({"user": newStatement})
     if "password" in requestObject:
         statement = requestObject["password"]
-        newStatement = rewiteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
+        newStatement = rewriteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
         if statement != newStatement:
             requestObject.update({"password": newStatement})
     if "command" in requestObject:
         statement = requestObject["command"]
-        newStatement = rewiteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
+        newStatement = rewriteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
         if statement != newStatement:
             requestObject.update({"command": newStatement})
 
@@ -104,9 +104,15 @@ def rewriteSshRequest(cls, requestObject, commandScriptFile: str):
             if "keyFile" in requestObject:
                 rewrotedCommand = rewrotedCommand + " KEYFILE " + requestObject["keyFile"]
         if requestObject["action"] == "execute":
-            rewrotedCommand = \
-                rewrotedCommand + "_SSH EXECUTE " + requestObject["command"]
-    return requestObject, [rewrotedCommand, ]
+            commandSplits = str(requestObject["command"]).split('\n')
+            rewrotedCommand = rewrotedCommand + " _SSH EXECUTE " + commandSplits[0]
+            if len(commandSplits) > 1:
+                for nIter in range(1, len(commandSplits)):
+                    rewrotedCommand = rewrotedCommand + "\nREWROTED    > " + commandSplits[nIter]
+    if len(rewrotedCommand) == 0:
+        return requestObject, []
+    else:
+        return requestObject, [rewrotedCommand, ]
 
 
 def executeSshRequest(requestObject):
@@ -140,7 +146,7 @@ def executeSshRequest(requestObject):
             sshContext.setSshTransport(sshHandler._transport)
 
             sftpHandler = sshHandler.open_sftp()
-            # 如果不适用chdir，则第一次getcwd永远返回的都是None
+            # 如果不使用chdir，则第一次getcwd永远返回的都是None
             sftpHandler.chdir(".")
             sshContext.setSftpHandler(sftpHandler)
 
@@ -238,6 +244,18 @@ def executeSshRequest(requestObject):
                             consoleOutputBytes = consoleOutputBytes + readByte
                     else:
                         break
+
+                # 处理回显的最后一行没有回车换行的情况
+                if len(consoleOutputBytes) != 0:
+                    yield {
+                        "type": "result",
+                        "title": None,
+                        "rows": None,
+                        "headers": None,
+                        "columnTypes": None,
+                        "status": consoleOutputBytes.decode(encoding='utf-8')
+                    }
+
                 # 获得命令的返回状态
                 ret = channel.recv_exit_status()
                 # 关闭SSH访问
