@@ -5,6 +5,7 @@ import re
 from .sqlparse import SQLFormatWithPrefix
 from .apiparse import APIRequestObjectFormatWithPrefix
 from .commands.assertExpression import evalExpression
+from .testcliexception import TestCliException
 
 
 def sortresult(result):
@@ -46,7 +47,7 @@ def sortresult(result):
                 result[j], result[i] = result[i], result[j]
 
 
-def rewiteStatement(cls, statement: str, commandScriptFile: str):
+def rewriteStatement(cls, statement: str, commandScriptFile: str):
     # 随后尝试被替换内容是否为当前应用变量，环境变量
     while True:
         # 替换脚本中的变量信息
@@ -69,8 +70,12 @@ def rewiteStatement(cls, statement: str, commandScriptFile: str):
                 if varName != evalResult:
                     statement = statement.replace(searchResult, str(evalResult))
             except NameError:
-                # 非环境变量
+                # 非本地变量
                 pass
+            except Exception as ex:
+                if "TESTCLI_DEBUG" in os.environ:
+                    raise TestCliException("evalExpression Error [" + varName + "]: [" + repr(ex) + "].")
+
             # 尝试环境变量
             if varName in os.environ:
                 statement = statement.replace(searchResult, os.environ[varName])
@@ -92,7 +97,7 @@ def rewriteHintStatement(cls, statement: str, commandScriptFile: str):
     rawStatement = statement
 
     # 开始替换
-    statement = rewiteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
+    statement = rewriteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
 
     if rawStatement != statement:
         # 记录被变量信息改写的命令
@@ -109,7 +114,7 @@ def rewriteSQLStatement(cls, statement: str, commandScriptFile: str):
     rawStatement = statement
 
     # 开始替换
-    statement = rewiteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
+    statement = rewriteStatement(cls=cls, statement=statement, commandScriptFile=commandScriptFile)
 
     # 语句发生了变化
     if rawStatement != statement:
@@ -130,7 +135,7 @@ def rewriteConnectRequest(cls, connectRequestObject, commandScriptFile: str):
     for keyword in ["username", "password", "driver", "driverSchema", "driverType", "host", "port", "service"]:
         if keyword in connectRequestObject:
             oldType = type(connectRequestObject[keyword])
-            newValue = rewiteStatement(
+            newValue = rewriteStatement(
                 cls=cls, statement=str(connectRequestObject[keyword]),
                 commandScriptFile=commandScriptFile)
             newValue = oldType(newValue)
@@ -171,7 +176,7 @@ def rewriteAPIStatement(cls, requestObject: [], commandScriptFile: str):
     rawRequestObject = copy.copy(requestObject)
 
     # 替换请求目标的信息
-    httpRequestTarget = rewiteStatement(
+    httpRequestTarget = rewriteStatement(
         cls=cls,
         statement=rawRequestObject["httpRequestTarget"],
         commandScriptFile=commandScriptFile)
@@ -181,7 +186,7 @@ def rewriteAPIStatement(cls, requestObject: [], commandScriptFile: str):
         httpRequestContents = copy.copy(rawRequestObject["contents"])
         # 开始替换
         for nPos in range(0, len(httpRequestContents)):
-            newHttpRequestContent = rewiteStatement(
+            newHttpRequestContent = rewriteStatement(
                 cls=cls,
                 statement=httpRequestContents[nPos],
                 commandScriptFile=commandScriptFile)
@@ -198,14 +203,14 @@ def rewriteAPIStatement(cls, requestObject: [], commandScriptFile: str):
         httpRequestFields = copy.copy(rawRequestObject["httpFields"])
         for key, value in httpRequestFields.items():
             originFieldName = key
-            key = rewiteStatement(
+            key = rewriteStatement(
                 cls=cls,
                 statement=originFieldName,
                 commandScriptFile=commandScriptFile)
             if originFieldName != key:
                 # 替换Fields中的Field字段
                 del httpRequestFields[originFieldName]
-            value = rewiteStatement(
+            value = rewriteStatement(
                 cls=cls,
                 statement=value,
                 commandScriptFile=commandScriptFile)
@@ -214,6 +219,25 @@ def rewriteAPIStatement(cls, requestObject: [], commandScriptFile: str):
     else:
         httpRequestFields = None
 
+    # 替换operate信息
+    if "operate" in rawRequestObject:
+        operateList = []
+        for operate in rawRequestObject["operate"]:
+            content = operate["content"]
+            content = rewriteStatement(
+                cls=cls,
+                statement=content,
+                commandScriptFile=commandScriptFile)
+            operateList.append(
+                {
+                    "operator": operate["operator"],
+                    "content": content
+                }
+            )
+        requestObject["operate"] = operateList
+    else:
+        requestObject["operate"] = None
+
     # 更新回原请求对象
     requestObject["httpRequestTarget"] = httpRequestTarget
     if httpRequestContents is not None:
@@ -323,7 +347,7 @@ def parseAPIHints(commandHints: list):
             r"^LogFilter(\s+)(.*)", commandHint, re.IGNORECASE | re.DOTALL)
         if match_obj:
             # 可能有多个Filter信息
-            sqlFilter = match_obj.group(5).strip()
+            sqlFilter = match_obj.group(2).strip()
             if "LogFilter" in commandHintList:
                 commandHintList["LogFilter"].append(sqlFilter)
             else:
@@ -334,11 +358,22 @@ def parseAPIHints(commandHints: list):
         match_obj = re.search(
             r"^LogMask(\s+)(.*)", commandHint, re.IGNORECASE | re.DOTALL)
         if match_obj:
-            sqlMask = match_obj.group(5).strip()
+            sqlMask = match_obj.group(2).strip()
             if "LogMask" in commandHintList:
                 commandHintList["LogMask"].append(sqlMask)
             else:
                 commandHintList["LogMask"] = [sqlMask]
             continue
 
+        # [Hint] JsonFilter   -- 如果输出结果为Json格式，则按照Json的格式过滤，这对于API测试比较有用
+        match_obj = re.search(
+            r"^JsonFilter(\s+)(.*)", commandHint, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            sqlMask = match_obj.group(2).strip()
+            if "JsonFilter" in commandHintList:
+                commandHintList["JsonFilter"].append(sqlMask)
+            else:
+                commandHintList["JsonFilter"] = [sqlMask]
+            continue
+
     return commandHintList
