@@ -304,7 +304,12 @@ class SQLVisitor(SQLParserVisitor):
     def visitConnectPassword(self, ctx: SQLParser.ConnectPasswordContext):
         parsedObject = {}
         if ctx.CONNECT_STRING() is not None:
-            parsedObject.update({'password': ctx.CONNECT_STRING().getText()})
+            password = str(ctx.CONNECT_STRING().getText()).strip()
+            if password.startswith('"') and password.endswith('"'):
+                password = password[1:-1]
+            elif password.startswith("'") and password.endswith("'"):
+                password = password[1:-1]
+            parsedObject.update({'password': password})
 
         # 获取错误代码
         errorCode = 0
@@ -499,10 +504,19 @@ class SQLVisitor(SQLParserVisitor):
             parsedObject.update({"rule": "BREAK"})
         elif ctx.LOOP_CONTINUE():
             parsedObject.update({"rule": "CONTINUE"})
-        elif ctx.LOOP_BEGIN():
-            parsedObject.update({"rule": "BEGIN"})
-        else:
-            parsedObject.update({"rule": "UNTIL"})
+        elif ctx.LOOP_UNTIL():
+            if ctx.LOOP_BEGIN() is not None:
+                parsedObject.update({"rule": "BEGIN"})
+            else:
+                parsedObject.update({"rule": "UNTIL"})
+                # 如果有两个INT，则第一个是最大循环次数，第二个是循环间隔
+                # 如果只有一个INT，则第一个是循环间隔，没有最大循环次数
+                if len(list(ctx.LOOP_INT())) == 2:
+                    parsedObject.update({"interval": int(ctx.LOOP_INT()[1].getText())})
+                    parsedObject.update({"limit": int(ctx.LOOP_INT()[0].getText())})
+                else:
+                    parsedObject.update({"interval": int(ctx.LOOP_INT()[0].getText())})
+                    parsedObject.update({"limit": -1})
         if ctx.LOOP_EXPRESSION() is not None:
             expression = str(ctx.LOOP_EXPRESSION().getText())
             if expression.startswith("{%"):
@@ -510,7 +524,7 @@ class SQLVisitor(SQLParserVisitor):
             if expression.endswith("%}"):
                 expression = expression[:-2]
             expression = expression.strip()
-            parsedObject.update({"UNTIL": expression})
+            parsedObject.update({"until": expression})
 
         # 处理错误信息
         errorCode = 0
@@ -1152,9 +1166,21 @@ class SQLVisitor(SQLParserVisitor):
         self.errorMsg = errorMsg
 
     def visitSpool(self, ctx: SQLParser.SpoolContext):
-        content = ctx.String().getText()
-        
-        parsedObject = {'name': 'SPOOL', 'file': content}
+        if ctx.SPOOL_EXPRESSION() is not None:
+            content = str(ctx.SPOOL_EXPRESSION().getText()).strip()
+            if content.startswith("'") and content.endswith("'"):
+                content = content[1:-1]
+            elif content.startswith('"') and content.endswith('"'):
+                content = content[1:-1]
+        else:
+            content = ""
+
+        if ctx.SPOOL_OFF() is not None:
+            content = "OFF"
+        parsedObject = {
+            'name': 'SPOOL',
+            'file': content
+        }
 
         # 获取错误代码
         errorCode = 0
