@@ -4,7 +4,6 @@ import sys
 import traceback
 import re
 import time
-from xml.sax import saxutils
 import sqlite3
 import setproctitle
 import click
@@ -13,6 +12,7 @@ import unicodedata
 import itertools
 import urllib3
 from time import strftime, localtime
+from xml.sax import saxutils
 
 from prompt_toolkit.history import FileHistory
 from prompt_toolkit.shortcuts import PromptSession
@@ -20,7 +20,6 @@ from prompt_toolkit.formatted_text import HTML
 
 from .cmdexecute import CmdExecute
 from .cmdmapping import CmdMapping
-from .hdfswrapper import HDFSWrapper
 from .testcliexception import TestCliException
 from .testclijobmanager import TestCliMeta
 from .testclijobmanager import JOBManager
@@ -81,13 +80,13 @@ class TestCli(object):
     ):
         self.Version = __version__                      # 当前程序版本
 
-        self.db_saved_conn = {}                         # 数据库Session备份
+        self.db_saved_conn = {}                         # 数据库Session对象，可能存在多个Session，并存在切换需要
+        self.api_saved_conn = {}                        # HTTP请求Session对象，可能存在多个Session，并存在切换需要
 
         self.cmdMappingHandler = CmdMapping()           # 函数句柄，处理SQLMapping信息
         self.cmdExecuteHandler = CmdExecute()           # 函数句柄，具体来执行语句
-        self.httpHandler = urllib3.PoolManager()        # Http请求线程池，用于处理API请求
+
         self.testOptions = TestOptions()                # 程序运行中各种参数
-        self.HdfsHandler = HDFSWrapper()                # HDFS文件操作
         self.JobHandler = JOBManager()                  # 并发任务管理器
         self.MetaHandler = TestCliMeta()                # SQLCli元数据
         self.SpoolFileHandler = []                      # Spool文件句柄, 是一个数组，可能发生嵌套
@@ -117,6 +116,16 @@ class TestCli(object):
         self.db_service = None                          # 数据库连接服务
         self.db_parameters = None                       # 数据库连接额外参数
 
+        # 当前Http请求的信息
+        self.httpSessionName = "DEFAULT"                # 当前Http会话的名称
+
+        # HTTP请求Session对象，可能存在多个Session，并存在切换需要
+        self.api_saved_conn = {
+            self.httpSessionName: {"https_verify": None, "http_proxy": None}
+        }
+        # 禁用urllib3的各种告警信息
+        urllib3.disable_warnings()
+
         # 如果没有标准输出和标准错误输出，则不输出。不报错
         if not sys.stdout.isatty():
             sys.stdout = open(os.devnull, mode="w")
@@ -750,6 +759,11 @@ class TestCli(object):
             self.logfile.close()
             self.logfile = None
 
+        # 关闭扩展日志的句柄
+        if self.xlogFileHandle is not None:
+            self.xlogFileHandle.close()
+            self.xlogFileHandle = None
+
         # 还原进程标题
         setproctitle.setproctitle(cliProcessTitleBak)
 
